{% macro large_card(icon_class, title, contents) %}
<div class="card shadow h-100 m-1 large-card">
    <div class="card-header">
        <h6 class="m-0 font-weight-bold text-primary">
            <i class="{{ icon_class }}"></i>
            {{ title }}
        </h6>
    </div>

    <div class="card-body">
        <div class="card-text">
            {{ contents|safe }}
        </div>
    </div>
</div>
{% endmacro %}

{% macro as_code_block(content) %}
<div class="code-block">
    <pre><code>{{ content }}</code></pre>
</div>

{% endmacro %}