<nav class="sb-topnav navbar navbar-expand navbar-dark bg-dark">
    <!-- Sidebar Toggle-->
    <button class="btn btn-link btn-sm order-1 order-lg-0 me-4 me-lg-0" id="sidebarToggle" href="#!"><i
            class="fas fa-bars"></i></button>

    <!-- Navbar-->
    <div class="container-fluid">
        <!-- Navbar Brand-->
        <a class="navbar-brand ps-3" href="#">
            {# <img src="{{ relative_path_to_root|default(" .") }}/static/images/brand.png"
                style="width: 80%; height: auto;" alt="logo"> #}
        </a>

        <!-- Navbar Menu-->
        <ul class="navbar-nav ms-auto ms-md-0 me-3 me-lg-4">
            <li class="nav-item m-3">
                <a href="./about.html" class="nav-link">About</a>
            </li>

            <li class="nav-item dropdown m-3">
                <a class="nav-link dropdown-toggle" id="navbarDropdown" href="#" role="button" data-bs-toggle="dropdown"
                    aria-expanded="false">Development</a>
                <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="navbarDropdown">
                    <li><a class="dropdown-item" href="#!">Sourcecode on Gitlab</a></li>
                </ul>
            </li>
        </ul>
    </div>
</nav>