{% macro small_card(icon_class, title, value, highlight_color) %}
<div class="col-xl-3 col-md-6 mb-4">
    <div class="card shadow h-100 py-2 small-card {{ highlight_color }}">
        <div class="card-body">
            <div class="row no-gutters align-items-center">
                <div class="col mr-2">
                    <div class="text-xs font-weight-bold text-primary text-uppercase mb-1">{{ title }}</div>
                    <div class="h5 mb-0 font-weight-bold text-gray-800">{{ value }}</div>
                </div>
                <div class="col-auto">
                    <i class="{{ icon_class }} fa-2x text-gray-300"></i>
                </div>
            </div>
        </div>
    </div>
</div>
{% endmacro %}