{% macro nav_item(icon_class, badge_class, count) %}
<li class="nav-item dropdown no-arrow mx-1">
    <i class="{{ icon_class }} alert-icon"></i>
    <span class="position-absolute top-0 start-100 translate-middle badge rounded-pill {{ badge_class }}">
        {{ count }}
    </span>
</li>
{% endmacro %}